package de.unibi.airobots.bonsai.actuators;

import java.io.IOException;

import de.unibi.airobots.btl.data.CameraPositionData;
import de.unibi.airobots.btl.data.CameraTargetData;
import de.unibi.airobots.bonsai.core.Actuator;
import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.sensors.data.PersonList;

/**
 * New interface to control a pan-tilt camera.
 * 
 * @author lziegler
 * @author ttoenige
 */
public interface CameraActuator extends Actuator {

    /**
     * Possible camera speeds.
     * 
     * @author lziegler
     */
    public enum CameraSpeed {
        SLOW, MEDIUM, FAST
    };

    /**
     * Set a target for the camera to look at.
     * 
     * @param target
     *            The target to look at.
     * @throws IOException
     *             Is thrown if some communication error occure.
     */
    void setTarget(CameraTargetData target) throws IOException;

    /**
     * Getter for the height of the camera above the ground.
     * 
     * @return height in mm.
     * @throws IOException
     *             Is thrown if some communication error occure.
     */
    long getCameraHeight() throws IOException;

    /**
     * Set a pan/tilt/zoom position of the camera.
     * 
     * @param position
     *            The position to move to.
     * @throws IOException
     *             Is thrown if some communication error occure.
     */
    void setPosition(CameraPositionData position) throws IOException;

    /**
     * Set the speed pan and tilt movements are done.
     * 
     * @param speed
     *            The speed used for pan and tilt movements.
     * 
     * @throws IOException
     *             Is thrown if some communication error occure.
     */
    void setSpeed(CameraSpeed speed) throws IOException;

    /**
     * Getter for the current pan/tilt/zoom values of the camera.
     * 
     * @return The current position.
     * @throws IOException
     *             Is thrown if some communication error occure.
     */
    CameraPositionData getPosition() throws IOException;

    /**
     * Focus a special person.
     * 
     * @param personID
     *            person to focus
     */
    void focus(Sensor<PersonList> personSensor, int personId) throws IOException;

    /**
     * stop focusing a special person
     */
    void unfocus() throws IOException;

    /**
     * start looking at persons
     */
    void startCamAction(Sensor<PersonList> personSensor) throws IOException;

    /**
     * stop looking at persons
     */
    void stopCamAction() throws IOException;
}
