package de.unibi.airobots.bonsai.actuators;

import java.io.IOException;

import de.unibi.airobots.bonsai.core.Actuator;

/**
 * This is a remote control interface to manipulate chains and tunnels in an
 * icewing instance, that runs a XcfChainSwitch plugin.
 * 
 * @author lziegler
 */
public interface IcewingChainSwitchActuator extends Actuator {

    /**
     * Deacitvates a chain.
     * 
     * @param name
     *            The name of the chain to deactive.
     * @throws IOException
     *             Is thrown when a communication error occurs.
     */
    void deactivateChain(String name) throws IOException;

    /**
     * Acitvates a chain.
     * 
     * @param name
     *            The name of the chain to active.
     * @throws IOException
     *             Is thrown when a communication error occurs.
     */
    void activateChain(String name) throws IOException;

    /**
     * Deacitvates a tunnel.
     * 
     * @param name
     *            The name of the tunnel to deactive.
     * @throws IOException
     *             Is thrown when a communication error occurs.
     */
    void deactivateTunnel(String name) throws IOException;

    /**
     * Acitvates a tunnel.
     * 
     * @param name
     *            The name of the tunnel to active.
     * @throws IOException
     *             Is thrown when a communication error occurs.
     */
    void activateTunnel(String name) throws IOException;

}
