package de.unibi.airobots.bonsai.actuators;

import java.io.IOException;

import de.unibi.airobots.bonsai.core.Actuator;
import de.unibi.airobots.btl.data.GoalReachedData;
import de.unibi.airobots.btl.data.NavigationGoalData;

/**
 * Base interface for all actuators that control the robots pose.
 * 
 * @author jwienke
 */
public interface NavigationActuator extends Actuator {

    /**
     * Sets a new goal to move to.
     * 
     * @param data
     *            new goal
     * @throws IOException
     *             communication error
     */
    void setGoal(NavigationGoalData data) throws IOException;

    /**
     * Check whether the last set goal was reached.
     * 
     * @return encapsulation of reached answer
     * @throws IOException
     *             communication error
     */
    GoalReachedData isGoalReached() throws IOException;

    /**
     * Manually stop the robot as fast as possible.
     * 
     * @throws IOException
     *             communication error
     */
    void manualStop() throws IOException;

    /**
     * Getter for the current navigation goal.
     * 
     * @return An instance of {@link NavigationGoalData} representing the
     *         current goal of the navigation algorithm.
     * @throws IOException
     *             communication error
     */
    NavigationGoalData getCurrentGoal() throws IOException;

}
