package de.unibi.airobots.bonsai.examples;

import java.net.URL;

import org.apache.log4j.BasicConfigurator;

import de.unibi.airobots.bonsai.core.BonsaiManager;
import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.core.SensorListener;
import de.unibi.airobots.bonsai.xcf.sensors.XcfBtlPublisherSensor;
import de.unibi.airobots.btl.data.LaserData;

/**
 * Test program for the {@link XcfBtlPublisherSensor} and its reconnection
 * capabilities.
 * 
 * @author jwienke
 */
public class SimpleXcfSensorTest {

    /**
     * Main method.
     * 
     * @param args
     *            command line arguments
     * @throws Exception
     *             error
     */
    public static void main(String[] args) throws Exception {

        BasicConfigurator.configure();

        try {

            URL configUrl = SimpleXcfSensorTest.class.getResource("loader.xml");
            if (configUrl == null) {
                System.err.println("Config not found.");
                System.exit(1);
            }

            BonsaiManager.getInstance().configure(configUrl.toURI());

            System.out.println("Can create laser data subscriber: "
                    + BonsaiManager.getInstance().canCreateSensor(
                            "LaserSensor", LaserData.class));

            Sensor<LaserData> laserSensor = BonsaiManager.getInstance()
                    .createSensor("LaserSensor", LaserData.class);

            laserSensor.addSensorListener(new SensorListener<LaserData>() {

                @Override
                public void newDataAvailable(LaserData newData) {
                    System.out.println("Async: " + newData);
                }

            });

            while (true) {
                // System.out.println(laserSensor.readLast());
                // CHECKSTYLE:OFF
                Thread.sleep(500);
                // CHECKSTYLE:ON
            }

            // CHECKSTYLE:OFF
        } catch (Exception e) {
            // CHECKSTYLE:ON
            e.printStackTrace();
            System.exit(1);
        }

    }
}
