package de.unibi.airobots.bonsai.examples;

import java.net.URISyntaxException;

import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

import de.unibi.airobots.bonsai.actuators.NavigationActuator;
import de.unibi.airobots.bonsai.core.BonsaiManager;
import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.core.BonsaiManager.ConfigurationException;
import de.unibi.airobots.bonsai.util.slam.SlamAnnotationTools;
import de.unibi.airobots.btl.data.BinarySlamMap;
import de.unibi.airobots.btl.data.PositionData;

public class SlamAnnotation {

    /**
     * Startup main-method.
     * 
     * @param args
     *            none
     */
    public static void main(String[] args) {
        try {
            new SlamAnnotation();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

    /**
     * Initialization of ...
     */

    /**
     * ... the logger
     */
    private static final Logger LOGGER = Logger.getLogger(BasicRemote.class);

    /**
     * Constructor.
     * 
     * @throws URISyntaxException
     * @throws ConfigurationException
     * @throws IllegalStateException
     */
    public SlamAnnotation() throws IllegalStateException,
            ConfigurationException, URISyntaxException {

        /**
         * Setting up the actuators and sensors
         */

        /*
         * While programming Biron one can send information to the logger. First
         * of all you need to initialize the logger and configure it.
         */
        BasicConfigurator.configure();

        /*
         * As there may be different situations in which something is logged
         * there are different logging levels. For example there is:
         * .info(message) .debug(message) .fatal(message) .error(message)
         * .warn(message) Moreover one can configure the logger and set a level
         * so that it will only show logged messages in this level.
         */
        LOGGER.info("setting up...");

        /*
         * Each actuator and sensor has its own manager, organizing each
         * actuators/sensors availability status. First one have to create a new
         * manager (if there is none yet). After that it is possible to get the
         * actuator/sensor itself but requesting it from the manager:
         * 
         * managerOfYourChoice.getActuator(); (or .getSensor();)
         * 
         * As the manager itself is not needed for the remaining interaction
         * with Biron there is also an alternative way to get the
         * actuator/sensor: The BonsaiFactory. It holds methods to create
         * Managers and allows you to create a manager and get get the reference
         * to the actuator/sensor immediately:
         * 
         * BonsaiFactory.getXManager().getActuator(); (X stands for any
         * actuator/sensor)
         */
        LOGGER.info("... NavigationManager ...");

        if (SlamAnnotation.class.getResource("./anotationHelper.xml") != null) {
            BonsaiManager.getInstance().configure(
                    SlamAnnotation.class.getResource("./anotationHelper.xml")
                            .toURI());

        } else {
            BonsaiManager.getInstance().configure(
                    "/vol/robocup/trunk/etc/bonsai_config/anotationHelper.xml");
        }

        Sensor<BinarySlamMap> slamSensor2 =
                BonsaiManager.getInstance().createSensor("SlamSensor",
                        BinarySlamMap.class);

        Sensor<PositionData> positionSensor = BonsaiManager.getInstance()
        .createSensor("PositionSensor", PositionData.class);
        
        NavigationActuator navigationActuator = BonsaiManager.getInstance().createActuator(
                "NavigationActuator", NavigationActuator.class);
        
        SlamAnnotationTools.showMapAnnotationWindow(slamSensor2, positionSensor, navigationActuator,
                "/vol/robocup/trunk/etc/SlamAnnotation/annotations.xml");

    }

}
