package de.unibi.airobots.bonsai.strategies.exploration;

import java.util.Vector;

import org.apache.log4j.Logger;

import de.unibi.airobots.bonsai.util.helper.annotation.MapRegion;
import de.unibi.airobots.btl.data.NavigationGoalData;
import de.unibi.airobots.btl.data.PositionData;
import de.unibi.airobots.btl.data.NavigationGoalData.GoalType;

public class ViewPointBasedSearchStrategy implements ExplorationStrategy {

    private Logger logger = Logger.getLogger(this.getClass());

    static final double COORDINATE_TOLERANCE = 0.5; // meters

    Vector<PositionData> allViewPoints = new Vector<PositionData>();
    Vector<PositionData> remainingViewPoints = new Vector<PositionData>();
    Vector<PositionData> missmatch = new Vector<PositionData>();

    void addViewPoint(PositionData point) {
        logger.debug("addPoint " + point);
        allViewPoints.add(point);
        remainingViewPoints.add(point);
    }

    void addMissMatchPoint(PositionData point) {
        missmatch.add(point);
    }

    void removeViewPoint(PositionData point) {
        allViewPoints.remove(point);
        remainingViewPoints.remove(point);
    }

    @Override
    public NavigationGoalData getNextGoal(PositionData currentPosition) {

        logger.info("getNextGoal");

        if (remainingViewPoints.isEmpty()) {
            if (missmatch.isEmpty())
                remainingViewPoints.addAll(allViewPoints);
            else
                remainingViewPoints.addAll(missmatch);
        }

        logger.debug(remainingViewPoints);

        logger.debug("currentPosition " + currentPosition);

        double minDist = Double.MAX_VALUE;
        PositionData minDistPos = null;
        for (PositionData p : remainingViewPoints) {
            logger.debug("PositionData " + p);
            double d =
                    Math.sqrt(Math.pow(p.getX() - currentPosition.getX(), 2)
                            + Math.pow(p.getY() - currentPosition.getY(), 2));
            logger.debug("minDist " + minDist + " d " + d);
            if (d < minDist) {
                minDist = d;
                minDistPos = p;
            }
        }
        remainingViewPoints.remove(minDistPos);
        logger.debug("goarl " + minDistPos);
        NavigationGoalData goal = new NavigationGoalData(minDistPos);
        goal.setCoordinateTolerance(COORDINATE_TOLERANCE);
        goal.setType(GoalType.GLOBAL);
        return goal;
    }

    @Override
    public NavigationGoalData getNextGoal(PositionData currentPosition,
            MapRegion roomPosition) {
        logger.info("getNextGoal");

        if (remainingViewPoints.isEmpty()) {
            if (missmatch.isEmpty())
                remainingViewPoints.addAll(allViewPoints);
            else
                remainingViewPoints.addAll(missmatch);
        }

        logger.debug(remainingViewPoints);

        logger.debug("currentPosition " + currentPosition);

        double minDist = Double.MAX_VALUE;
        PositionData minDistPos = null;
        for (PositionData p : remainingViewPoints) {
            logger.debug("PositionData " + p);
            logger.debug("roomPosition " + roomPosition.getShape());
            double d =
                    Math.sqrt(Math.pow(p.getX() - currentPosition.getX(), 2)
                            + Math.pow(p.getY() - currentPosition.getY(), 2));
            logger.debug("minDist " + minDist + " d " + d);
            if (d < minDist && roomPosition.contains(p.getX(), p.getY())) {
                minDist = d;
                minDistPos = p;
            }
        }
        remainingViewPoints.remove(minDistPos);
        logger.debug("goarl " + minDistPos);
        if (minDistPos == null)
            minDistPos = roomPosition.getViewPoint();
        NavigationGoalData goal = new NavigationGoalData(minDistPos);
        goal.setCoordinateTolerance(COORDINATE_TOLERANCE);
        goal.setType(GoalType.GLOBAL);
        return goal;
    }

}
