package de.unibi.airobots.bonsai.util.helper;

import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.ListIterator;

/**
 * A kind of queue that only stores the last n added elements. Older elements
 * are removed if a new one is added.
 * 
 * @author jwienke
 * 
 * @param <E>
 *            type of the elements
 */
public class ConstantSizeQueue<E> implements List<E> {

	private int size;
	private List<E> storage = new LinkedList<E>();

	public ConstantSizeQueue(int size) {
		this.size = size;
	}

	@Override
	public boolean add(E e) {

		if (storage.size() >= size) {
			storage.remove(0);
			storage.add(e);
			return true;
		} else {
			return storage.add(e);
		}

	}

	@Override
	public boolean addAll(Collection<? extends E> c) {
		return false;
	}

	@Override
	public void clear() {
		storage.clear();
	}

	@Override
	public boolean contains(Object o) {
		return storage.contains(o);
	}

	@Override
	public boolean containsAll(Collection<?> c) {
		return storage.containsAll(c);
	}

	@Override
	public boolean isEmpty() {
		return storage.isEmpty();
	}

	@Override
	public Iterator<E> iterator() {
		return storage.iterator();
	}

	@Override
	public boolean remove(Object o) {
		return storage.remove(o);
	}

	@Override
	public boolean removeAll(Collection<?> c) {
		return storage.removeAll(c);
	}

	@Override
	public boolean retainAll(Collection<?> c) {
		return storage.retainAll(c);
	}

	@Override
	public int size() {
		return storage.size();
	}

	@Override
	public Object[] toArray() {
		return storage.toArray();
	}

	@Override
	public <T> T[] toArray(T[] a) {
		return storage.toArray(a);
	}

	@Override
	public void add(int index, E element) {
		if (storage.size() >= size) {
			storage.remove(0);
		}
		storage.add(index, element);
	}

	@Override
	public boolean addAll(int index, Collection<? extends E> c) {
		return false;
	}

	@Override
	public E get(int index) {
		return storage.get(index);
	}

	@Override
	public int indexOf(Object o) {
		return storage.indexOf(o);
	}

	@Override
	public int lastIndexOf(Object o) {
		return storage.lastIndexOf(o);
	}

	@Override
	public ListIterator<E> listIterator() {
		return storage.listIterator();
	}

	@Override
	public ListIterator<E> listIterator(int index) {
		return storage.listIterator(index);
	}

	@Override
	public E remove(int index) {
		return storage.remove(index);
	}

	@Override
	public E set(int index, E element) {
		return null;
	}

	@Override
	public List<E> subList(int fromIndex, int toIndex) {
		return storage.subList(fromIndex, toIndex);
	}

}
