package de.unibi.airobots.bonsai.xcf.actuators;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import org.apache.log4j.Logger;

import de.unibi.airobots.bonsai.actuators.IcewingChainSwitchActuator;
import de.unibi.airobots.bonsai.xcf.RemoteServerReconnectable;

import net.sf.xcf.MethodNotFoundException;
import net.sf.xcf.RemoteServer;
import net.sf.xcf.UserException;
import net.sf.xcf.transport.XOPData;
import nu.xom.Attribute;
import nu.xom.Document;
import nu.xom.Element;

/**
 * This class allows you to (de-) activate icewing chains.
 * 
 * @author lziegler
 */
public class XcfIcewingChainSwitchActuator implements
        RemoteServerReconnectable, IcewingChainSwitchActuator {

    private Logger logger = Logger.getLogger(getClass());

    private static final String BASE_TAG = "Chain";
    private static final String NAME_TAG = "name";
    private static final String METHOD_DEACTIVE = "deactivate";
    private static final String METHOD_ACTIVE = "activate";
    private static final String ERROR_METHOD_NOT_FOUND =
            "The method is not registered on the server.";

    private String remoteServerName;
    private Object remoteServerLock = new Object();
    private RemoteServer remoteServer;

    /**
     * Constructor.
     * 
     * @param remoteServerName
     *            name of the remote server used to control the swiss ranger
     */
    public XcfIcewingChainSwitchActuator(String remoteServerName) {
        this.remoteServerName = remoteServerName;
    }

    @Override
    public void deactivateChain(String name) throws IOException {

        Element elem = new Element(BASE_TAG);
        elem.addAttribute(new Attribute(NAME_TAG, name));
        Document d = new Document(elem);
        XOPData doc = new XOPData(d);

        try {
            XOPData res;
            synchronized (remoteServerLock) {
                res = this.remoteServer.callMethod(METHOD_DEACTIVE, doc);
            }
            logger.debug(res.getDocument().toString());
        } catch (MethodNotFoundException e) {
            logger.debug(ERROR_METHOD_NOT_FOUND, e);
            throw new IOException(e);
        } catch (UserException e) {
            throw new IOException(e);
        }

    }

    @Override
    public void activateChain(String name) throws IOException {

        Element elem = new Element(BASE_TAG);
        elem.addAttribute(new Attribute(NAME_TAG, name));
        Document d = new Document(elem);
        XOPData doc = new XOPData(d);

        try {
            XOPData res;
            synchronized (remoteServerLock) {
                res = this.remoteServer.callMethod(METHOD_ACTIVE, doc);
            }
            logger.debug(res.getDocument());
        } catch (MethodNotFoundException e) {
            logger.debug(ERROR_METHOD_NOT_FOUND, e);
            throw new IOException(e);
        } catch (UserException e) {
            throw new IOException(e);
        }

    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Map<String, ErrorHandlingPolicy> getRemoteServerNames() {
        Map<String, ErrorHandlingPolicy> servers =
                new HashMap<String, ErrorHandlingPolicy>();
        servers.put(remoteServerName, ErrorHandlingPolicy.SELF_HEALING);
        return servers;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void resetRemoteServer(RemoteServer remoteServer) {
        synchronized (remoteServerLock) {
            this.remoteServer = remoteServer;
        }

    }

    @Override
    public void deactivateTunnel(String name) throws IOException {
        // TODO implement this!
        throw new RuntimeException("Not implemented yet!");
    }

    @Override
    public void activateTunnel(String name) throws IOException {
     // TODO implement this!
        throw new RuntimeException("Not implemented yet!");
    }

}
