package de.unibi.airobots.bonsai.xcf.configuration;

import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.core.CoreObjectFactory.SensorToConfigure;
import de.unibi.airobots.bonsai.xcf.sensors.XcfBtlPublisherSensor;
import de.unibi.airobots.btl.data.Type;

/**
 * Configuration for {@link XcfBtlPublisherSensor}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@link ConfiguredXcfSensor#OPTION_PUBLISHER_NAME} (required): name of the
 * publisher to register on</li>
 * </ul>
 * 
 * @author jwienke
 * @param <T>
 *            sensor data type
 */
public class ConfiguredXcfBtlPublisherSensor<T extends Type> extends
        ConfiguredXcfSensor<T> {

    /**
     * {@inheritDoc}
     */
    @Override
    public Sensor<T> createInstance() {
        return new XcfBtlPublisherSensor<T>(getDataType(), getPublisherName());
    }

    /**
     * Checks if the sensor that can be produced is suitable for the requested
     * configuration.
     * 
     * @param sensor
     *            requested configuration
     * @return <code>true</code> if suitable
     */
    public static boolean isSuitableFor(SensorToConfigure sensor) {
        return sensor.getSensorClass().equals(XcfBtlPublisherSensor.class)
                && Type.class.isAssignableFrom(sensor.getDataTypeClass());
    }

}
