package de.unibi.airobots.bonsai.xcf.configuration;

import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.core.CoreObjectFactory.SensorToConfigure;
import de.unibi.airobots.bonsai.sensors.data.ImageData;
import de.unibi.airobots.bonsai.xcf.sensors.XcfCameraSensor;

/**
 * Configuration for {@link XcfCameraSensor}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@link ConfiguredXcfSensor#OPTION_PUBLISHER_NAME} (required): name of the
 * publisher to receive images from</li>
 * </ul>
 * 
 * @author jwienke
 */
public class ConfiguredXcfCameraSensor extends ConfiguredXcfSensor<ImageData> {

    /**
     * {@inheritDoc}
     */
    @Override
    public Sensor<ImageData> createInstance() {
        return new XcfCameraSensor(getPublisherName());
    }

    /**
     * Checks if the sensor that can be produced is suitable for the requested
     * configuration.
     * 
     * @param sensor
     *            requested configuration
     * @return <code>true</code> if suitable
     */
    public static boolean isSuitableFor(SensorToConfigure sensor) {
        return sensor.getSensorClass().equals(XcfCameraSensor.class);
    }

}
