package de.unibi.airobots.bonsai.xcf.configuration;

import java.util.Map;

import de.unibi.airobots.bonsai.actuators.SceneActuator;
import de.unibi.airobots.bonsai.core.CoreObjectFactory.ActuatorToConfigure;
import de.unibi.airobots.bonsai.xcf.actuators.XcfSceneActuator;

/**
 * Configuration for {@link XcfSceneActuator}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@value #OPTION_MEMORY_NAME} (required): Name of the active memory that
 * contains the scene information</li>
 * </ul>
 * 
 * @author lziegler
 */
public class ConfiguredXcfSceneActuator extends ConfiguredXcfActuator {

    private String memoryName = "";

    /**
     * Name of the user option to specify the active memory for finding person
     * information.
     */
    public static final String OPTION_MEMORY_NAME = "memoryName";

    /**
     * {@inheritDoc}
     */
    @Override
    public void parseOptions(Map<String, String> options)
            throws IllegalArgumentException {

        if (!options.containsKey(OPTION_MEMORY_NAME)) {
            throw new IllegalArgumentException(
                    "Memory name missing with option " + OPTION_MEMORY_NAME);
        }

        memoryName = options.get(OPTION_MEMORY_NAME);

    }

    /**
     * {@inheritDoc}
     */
    @Override
    public SceneActuator createInstance() {
        return new XcfSceneActuator(memoryName);
    }

    /**
     * Checks if the sensor that can be produced is suitable for the requested
     * configuration.
     * 
     * @param sensor
     *            requested configuration
     * @return <code>true</code> if suitable
     */
    public static boolean isSuitableFor(ActuatorToConfigure actuator) {
        return actuator.getActuatorClass().equals(XcfSceneActuator.class);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String[] getActiveMemoriesToInitialize() {
        return new String[] { memoryName };
    }

}
