package de.unibi.airobots.bonsai.xcf.configuration;

import java.util.Map;

import de.unibi.airobots.bonsai.core.CoreObjectFactory.SensorToConfigure;
import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.xcf.sensors.XcfSceneGridMapSensor;
import de.unibi.airobots.btl.data.DynamicGridMap;

/**
 * Configuration for {@link XcfSceneGridMapSensor}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@value #OPTION_MEMORY_NAME} (required): Name of the active memory that
 * contains the scene information</li>
 * <li>{@value #OPTION_MAP_NAME} (required): Name of the map that contains the
 * scene information</li>
 * </ul>
 * 
 * @author lziegler
 */
public class ConfiguredXcfSceneGridMapSensor extends
        ConfiguredXcfSensor<DynamicGridMap> {

    private String memoryName = "";
    private String mapName = "";

    /**
     * Name of the user option to specify the active memory.
     */
    public static final String OPTION_MEMORY_NAME = "memoryName";

    /**
     * Name of the user option to specify the desired map name.
     */
    public static final String OPTION_MAP_NAME = "mapName";

    /**
     * {@inheritDoc}
     */
    @Override
    public void parseOptions(Map<String, String> options)
            throws IllegalArgumentException {

        if (!options.containsKey(OPTION_MEMORY_NAME)) {
            throw new IllegalArgumentException(
                    "Memory name missing with option " + OPTION_MEMORY_NAME);
        }

        if (!options.containsKey(OPTION_MAP_NAME)) {
            throw new IllegalArgumentException("Map name missing with option "
                    + OPTION_MAP_NAME);
        }

        memoryName = options.get(OPTION_MEMORY_NAME);
        mapName = options.get(OPTION_MAP_NAME);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Sensor<DynamicGridMap> createInstance() {
        return new XcfSceneGridMapSensor(memoryName, mapName);
    }

    /**
     * Checks if the sensor that can be produced is suitable for the requested
     * configuration.
     * 
     * @param sensor
     *            requested configuration
     * @return <code>true</code> if suitable
     */
    public static boolean isSuitableFor(SensorToConfigure sensor) {
        return sensor.getSensorClass().equals(XcfSceneGridMapSensor.class);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String[] getSubscribersToInitialize() {
        return new String[0];
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String[] getActiveMemoriesToInitialize() {
        return new String[] { memoryName };
    }

}
