package de.unibi.airobots.bonsai.xcf.configuration;

import de.unibi.airobots.bonsai.core.Actuator;
import de.unibi.airobots.bonsai.core.CoreObjectFactory.ActuatorToConfigure;
import de.unibi.airobots.bonsai.xcf.actuators.XcfSwissRangerControl;

/**
 * Configuration object for {@link XcfSwissRangerControl}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@link ConfiguredXcfActuator#OPTION_SERVER_NAME} (required): name of the
 * server to control the swissranger</li>
 * </ul>
 * 
 * @author jwienke
 */
public class ConfiguredXcfSwissRangerControl extends ConfiguredXcfActuator {

    /**
     * Checks if the actuator that can be produced is suitable for the requested
     * configuration.
     * 
     * @param actuatorToConfigure
     *            requested configuration
     * @return <code>true</code> if suitable
     */
    public static boolean isSuitableFor(ActuatorToConfigure actuatorToConfigure) {
        return actuatorToConfigure.getActuatorClass().equals(
                XcfSwissRangerControl.class);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Actuator createInstance() {
        return new XcfSwissRangerControl(getServerName());
    }

}
